@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2026, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -24,39 +24,47 @@
  */
 
 /*
+ * UNICODE LICENSE V3
+ *
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
+ * Copyright © 1991-2025 Unicode, Inc.
  *
- * Permission is hereby granted, free of charge, to any person obtaining
- * a copy of the Unicode data files and any associated documentation
- * (the "Data Files") or Unicode software and any associated documentation
- * (the "Software") to deal in the Data Files or Software
- * without restriction, including without limitation the rights to use,
- * copy, modify, merge, publish, distribute, and/or sell copies of
- * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that either
- * (a) this copyright and permission notice appear with all copies
- * of the Data Files or Software, or
- * (b) this copyright and permission notice appear in associated
- * Documentation.
+ * NOTICE TO USER: Carefully read the following legal agreement. BY
+ * DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING DATA FILES, AND/OR
+ * SOFTWARE, YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
+ * TERMS AND CONDITIONS OF THIS AGREEMENT. IF YOU DO NOT AGREE, DO NOT
+ * DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE THE DATA FILES OR SOFTWARE.
  *
- * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
- * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
- * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
- * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
- * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
- * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
- * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
- * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
- * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
- * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
+ * Permission is hereby granted, free of charge, to any person obtaining a
+ * copy of data files and any associated documentation (the "Data Files") or
+ * software and any associated documentation (the "Software") to deal in the
+ * Data Files or Software without restriction, including without limitation
+ * the rights to use, copy, modify, merge, publish, distribute, and/or sell
+ * copies of the Data Files or Software, and to permit persons to whom the
+ * Data Files or Software are furnished to do so, provided that either (a)
+ * this copyright and permission notice appear with all copies of the Data
+ * Files or Software, or (b) this copyright and permission notice appear in
+ * associated Documentation.
  *
- * Except as contained in this notice, the name of a copyright holder
- * shall not be used in advertising or otherwise to promote the sale,
- * use or other dealings in these Data Files or Software without prior
- * written authorization of the copyright holder.
+ * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF ANY
+ * KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT OF
+ * THIRD PARTY RIGHTS.
+ *
+ * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS NOTICE
+ * BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL DAMAGES,
+ * OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
+ * WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
+ * ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THE DATA
+ * FILES OR SOFTWARE.
+ *
+ * Except as contained in this notice, the name of a copyright holder shall
+ * not be used in advertising or otherwise to promote the sale, use or other
+ * dealings in these Data Files or Software without prior written
+ * authorization of the copyright holder.
+ *
+ * SPDX-License-Identifier: Unicode-3.0
  */
 
 package sun.text.resources.cldr.ext;
@@ -178,6 +186,7 @@ public class FormatData_dsb extends ListResourceBundle {
         final String metaValue_generic_DateFormatItem_Ehms = "E, h:mm:ss a";
         final String metaValue_generic_DateFormatItem_Ehm = "E, h:mm a";
         final String metaValue_generic_DateFormatItem_yMEd = "E, d.M.y";
+        final String metaValue_generic_DateFormatItem_hv = "'zeg'. h a v";
         final String metaValue_generic_DateFormatItem_hms = "h:mm:ss a";
         final String metaValue_generic_DateFormatItem_yMMMd = "d. MMM y";
         final String metaValue_generic_DateFormatItem_yw = "w. 'tyźeń' 'lěta' Y";
@@ -186,13 +195,17 @@ public class FormatData_dsb extends ListResourceBundle {
         final String metaValue_generic_DateFormatItem_EHms = "E, HH:mm:ss";
         final String metaValue_generic_DateFormatItem_EHm = "E, 'zeg'. H:mm";
         final String metaValue_generic_DateFormatItem_yMMM = "MMM y";
+        final String metaValue_generic_DateFormatItem_Hv = "'zeg'. H v";
         final String metaValue_generic_DateFormatItem_Md = "d.M.";
         final String metaValue_generic_DateFormatItem_Ed = "E, d.";
         final String metaValue_generic_DateFormatItem_MMMMd = "d. MMMM";
         final String metaValue_generic_DateFormatItem_H = "'zeg'. H";
         final String metaValue_generic_DateFormatItem_MEd = "E, d.M.";
         final String metaValue_generic_DateFormatItem_MMMEd = "E, d. MMM";
+        final String metaValue_generic_DateFormatItem_GyMEd = "E, d.M.y G";
         final String metaValue_generic_DateFormatItem_d = "d.";
+        final String metaValue_generic_DateFormatItem_Bh = "'zeg'. h B";
+        final String metaValue_generic_DateFormatItem_EBh = "E, 'zeg'. h B";
         final String metaValue_generic_DateFormatItem_Hmsv = "H:mm:ss v";
         final String metaValue_generic_DateFormatItem_Hms = "H:mm:ss";
         final String metaValue_generic_DateFormatItem_Hmv = "H:mm v";
@@ -202,6 +215,7 @@ public class FormatData_dsb extends ListResourceBundle {
         final String metaValue_generic_DateFormatItem_yMMMM = "LLLL y";
         final String metaValue_generic_DateFormatItem_MMMMW = "W. 'tyźeń' MMMM";
         final String metaValue_generic_DateFormatItem_yQQQQ = "QQQQ y";
+        final String metaValue_generic_DateFormatItem_GyM = "M/y G";
         final String[] metaValue_MonthNames = new String[] {
             "januara",
             "februara",
@@ -280,6 +294,7 @@ public class FormatData_dsb extends ListResourceBundle {
             { "generic.DateFormatItem.yyyyQQQQ", "QQQQ y G" },
             { "generic.DateFormatItem.Ehm", metaValue_generic_DateFormatItem_Ehm },
             { "generic.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
+            { "generic.DateFormatItem.hv", metaValue_generic_DateFormatItem_hv },
             { "generic.DateFormatItem.hms", metaValue_generic_DateFormatItem_hms },
             { "generic.DateFormatItem.yyyyMMMd", metaValue_generic_DateFormatItem_yyyyMMMd },
             { "generic.DateFormatItem.Gy", metaValue_generic_DateFormatItem_Gy },
@@ -294,16 +309,20 @@ public class FormatData_dsb extends ListResourceBundle {
             { "generic.DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
             { "generic.DateFormatItem.yyyyMd", metaValue_generic_DateFormatItem_yyyyMd },
             { "generic.DateFormatItem.yMMM", metaValue_generic_DateFormatItem_yMMM },
+            { "generic.DateFormatItem.Hv", metaValue_generic_DateFormatItem_Hv },
             { "generic.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
             { "generic.DateFormatItem.Ed", metaValue_generic_DateFormatItem_Ed },
             { "generic.DateFormatItem.yyyyMMM", metaValue_generic_DateFormatItem_yyyyMMM },
+            { "generic.DateFormatItem.Eh", "E 'zeg'. h a" },
             { "generic.DateFormatItem.MMMMd", metaValue_generic_DateFormatItem_MMMMd },
             { "generic.DateFormatItem.H", metaValue_generic_DateFormatItem_H },
             { "generic.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
             { "generic.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
+            { "generic.DateFormatItem.GyMEd", metaValue_generic_DateFormatItem_GyMEd },
             { "generic.DateFormatItem.yyyyQQQ", "QQQ y G" },
             { "generic.DateFormatItem.d", metaValue_generic_DateFormatItem_d },
-            { "generic.DateFormatItem.Bh", "h 'hodź'. B" },
+            { "generic.DateFormatItem.Bh", metaValue_generic_DateFormatItem_Bh },
+            { "generic.DateFormatItem.EBh", metaValue_generic_DateFormatItem_EBh },
             { "generic.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
             { "generic.DateFormatItem.GyMd", metaValue_generic_DateFormatItem_yyyyMd },
             { "generic.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_yyyyMMMEd },
@@ -318,6 +337,7 @@ public class FormatData_dsb extends ListResourceBundle {
             { "generic.DateFormatItem.yQQQQ", metaValue_generic_DateFormatItem_yQQQQ },
             { "generic.DateFormatItem.yyyy", metaValue_generic_DateFormatItem_Gy },
             { "generic.DateFormatItem.y", metaValue_generic_DateFormatItem_Gy },
+            { "generic.DateFormatItem.GyM", metaValue_generic_DateFormatItem_GyM },
             { "generic.DateFormatItem.GyMMM", metaValue_generic_DateFormatItem_yyyyMMM },
             { "MonthNames", metaValue_MonthNames },
             { "standalone.MonthNames",
@@ -405,6 +425,7 @@ public class FormatData_dsb extends ListResourceBundle {
             { "DateFormatItem.Ehms", metaValue_generic_DateFormatItem_Ehms },
             { "DateFormatItem.Ehm", metaValue_generic_DateFormatItem_Ehm },
             { "DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
+            { "DateFormatItem.hv", metaValue_generic_DateFormatItem_hv },
             { "DateFormatItem.hms", metaValue_generic_DateFormatItem_hms },
             { "DateFormatItem.Gy", metaValue_generic_DateFormatItem_Gy },
             { "DateFormatItem.GyMMMd", metaValue_generic_DateFormatItem_yyyyMMMd },
@@ -415,13 +436,17 @@ public class FormatData_dsb extends ListResourceBundle {
             { "DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
             { "DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
             { "DateFormatItem.yMMM", metaValue_generic_DateFormatItem_yMMM },
+            { "DateFormatItem.Hv", metaValue_generic_DateFormatItem_Hv },
             { "DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
             { "DateFormatItem.Ed", metaValue_generic_DateFormatItem_Ed },
             { "DateFormatItem.MMMMd", metaValue_generic_DateFormatItem_MMMMd },
             { "DateFormatItem.H", metaValue_generic_DateFormatItem_H },
             { "DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
             { "DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
+            { "DateFormatItem.GyMEd", metaValue_generic_DateFormatItem_GyMEd },
             { "DateFormatItem.d", metaValue_generic_DateFormatItem_d },
+            { "DateFormatItem.Bh", metaValue_generic_DateFormatItem_Bh },
+            { "DateFormatItem.EBh", metaValue_generic_DateFormatItem_EBh },
             { "DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
             { "DateFormatItem.GyMd", metaValue_generic_DateFormatItem_yyyyMd },
             { "DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_yyyyMMMEd },
@@ -433,6 +458,7 @@ public class FormatData_dsb extends ListResourceBundle {
             { "DateFormatItem.yMMMM", metaValue_generic_DateFormatItem_yMMMM },
             { "DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
             { "DateFormatItem.yQQQQ", metaValue_generic_DateFormatItem_yQQQQ },
+            { "DateFormatItem.GyM", metaValue_generic_DateFormatItem_GyM },
             { "DateFormatItem.GyMMM", metaValue_generic_DateFormatItem_yyyyMMM },
             { "buddhist.MonthNames", metaValue_MonthNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
@@ -451,6 +477,7 @@ public class FormatData_dsb extends ListResourceBundle {
             { "buddhist.DateFormatItem.Ehms", metaValue_generic_DateFormatItem_Ehms },
             { "buddhist.DateFormatItem.Ehm", metaValue_generic_DateFormatItem_Ehm },
             { "buddhist.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
+            { "buddhist.DateFormatItem.hv", metaValue_generic_DateFormatItem_hv },
             { "buddhist.DateFormatItem.hms", metaValue_generic_DateFormatItem_hms },
             { "buddhist.DateFormatItem.Gy", metaValue_generic_DateFormatItem_Gy },
             { "buddhist.DateFormatItem.GyMMMd", metaValue_generic_DateFormatItem_yyyyMMMd },
@@ -461,14 +488,18 @@ public class FormatData_dsb extends ListResourceBundle {
             { "buddhist.DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
             { "buddhist.DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
             { "buddhist.DateFormatItem.yMMM", metaValue_generic_DateFormatItem_yMMM },
+            { "buddhist.DateFormatItem.Hv", metaValue_generic_DateFormatItem_Hv },
             { "buddhist.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
             { "buddhist.DateFormatItem.Ed", metaValue_generic_DateFormatItem_Ed },
             { "buddhist.DateFormatItem.MMMMd", metaValue_generic_DateFormatItem_MMMMd },
             { "buddhist.DateFormatItem.H", metaValue_generic_DateFormatItem_H },
             { "buddhist.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
             { "buddhist.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
+            { "buddhist.DateFormatItem.GyMEd", metaValue_generic_DateFormatItem_GyMEd },
             { "buddhist.DateFormatItem.d", metaValue_generic_DateFormatItem_d },
+            { "buddhist.DateFormatItem.Bh", metaValue_generic_DateFormatItem_Bh },
             { "buddhist.DateFormatItem.h", metaValue_buddhist_DateFormatItem_h },
+            { "buddhist.DateFormatItem.EBh", metaValue_generic_DateFormatItem_EBh },
             { "buddhist.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
             { "buddhist.DateFormatItem.GyMd", metaValue_generic_DateFormatItem_yyyyMd },
             { "buddhist.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_yyyyMMMEd },
@@ -480,6 +511,7 @@ public class FormatData_dsb extends ListResourceBundle {
             { "buddhist.DateFormatItem.yMMMM", metaValue_generic_DateFormatItem_yMMMM },
             { "buddhist.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
             { "buddhist.DateFormatItem.yQQQQ", metaValue_generic_DateFormatItem_yQQQQ },
+            { "buddhist.DateFormatItem.GyM", metaValue_generic_DateFormatItem_GyM },
             { "buddhist.DateFormatItem.GyMMM", metaValue_generic_DateFormatItem_yyyyMMM },
             { "japanese.MonthNames", metaValue_MonthNames },
             { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
@@ -504,6 +536,7 @@ public class FormatData_dsb extends ListResourceBundle {
             { "japanese.DateFormatItem.Ehms", metaValue_generic_DateFormatItem_Ehms },
             { "japanese.DateFormatItem.Ehm", metaValue_generic_DateFormatItem_Ehm },
             { "japanese.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
+            { "japanese.DateFormatItem.hv", metaValue_generic_DateFormatItem_hv },
             { "japanese.DateFormatItem.hms", metaValue_generic_DateFormatItem_hms },
             { "japanese.DateFormatItem.Gy", metaValue_generic_DateFormatItem_Gy },
             { "japanese.DateFormatItem.GyMMMd", metaValue_generic_DateFormatItem_yyyyMMMd },
@@ -514,14 +547,18 @@ public class FormatData_dsb extends ListResourceBundle {
             { "japanese.DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
             { "japanese.DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
             { "japanese.DateFormatItem.yMMM", metaValue_generic_DateFormatItem_yMMM },
+            { "japanese.DateFormatItem.Hv", metaValue_generic_DateFormatItem_Hv },
             { "japanese.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
             { "japanese.DateFormatItem.Ed", metaValue_generic_DateFormatItem_Ed },
             { "japanese.DateFormatItem.MMMMd", metaValue_generic_DateFormatItem_MMMMd },
             { "japanese.DateFormatItem.H", metaValue_generic_DateFormatItem_H },
             { "japanese.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
             { "japanese.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
+            { "japanese.DateFormatItem.GyMEd", metaValue_generic_DateFormatItem_GyMEd },
             { "japanese.DateFormatItem.d", metaValue_generic_DateFormatItem_d },
+            { "japanese.DateFormatItem.Bh", metaValue_generic_DateFormatItem_Bh },
             { "japanese.DateFormatItem.h", metaValue_buddhist_DateFormatItem_h },
+            { "japanese.DateFormatItem.EBh", metaValue_generic_DateFormatItem_EBh },
             { "japanese.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
             { "japanese.DateFormatItem.GyMd", metaValue_generic_DateFormatItem_yyyyMd },
             { "japanese.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_yyyyMMMEd },
@@ -533,6 +570,7 @@ public class FormatData_dsb extends ListResourceBundle {
             { "japanese.DateFormatItem.yMMMM", metaValue_generic_DateFormatItem_yMMMM },
             { "japanese.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
             { "japanese.DateFormatItem.yQQQQ", metaValue_generic_DateFormatItem_yQQQQ },
+            { "japanese.DateFormatItem.GyM", metaValue_generic_DateFormatItem_GyM },
             { "japanese.DateFormatItem.GyMMM", metaValue_generic_DateFormatItem_yyyyMMM },
             { "roc.MonthNames", metaValue_MonthNames },
             { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
@@ -551,6 +589,7 @@ public class FormatData_dsb extends ListResourceBundle {
             { "roc.DateFormatItem.Ehms", metaValue_generic_DateFormatItem_Ehms },
             { "roc.DateFormatItem.Ehm", metaValue_generic_DateFormatItem_Ehm },
             { "roc.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
+            { "roc.DateFormatItem.hv", metaValue_generic_DateFormatItem_hv },
             { "roc.DateFormatItem.hms", metaValue_generic_DateFormatItem_hms },
             { "roc.DateFormatItem.Gy", metaValue_generic_DateFormatItem_Gy },
             { "roc.DateFormatItem.GyMMMd", metaValue_generic_DateFormatItem_yyyyMMMd },
@@ -561,14 +600,18 @@ public class FormatData_dsb extends ListResourceBundle {
             { "roc.DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
             { "roc.DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
             { "roc.DateFormatItem.yMMM", metaValue_generic_DateFormatItem_yMMM },
+            { "roc.DateFormatItem.Hv", metaValue_generic_DateFormatItem_Hv },
             { "roc.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
             { "roc.DateFormatItem.Ed", metaValue_generic_DateFormatItem_Ed },
             { "roc.DateFormatItem.MMMMd", metaValue_generic_DateFormatItem_MMMMd },
             { "roc.DateFormatItem.H", metaValue_generic_DateFormatItem_H },
             { "roc.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
             { "roc.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
+            { "roc.DateFormatItem.GyMEd", metaValue_generic_DateFormatItem_GyMEd },
             { "roc.DateFormatItem.d", metaValue_generic_DateFormatItem_d },
+            { "roc.DateFormatItem.Bh", metaValue_generic_DateFormatItem_Bh },
             { "roc.DateFormatItem.h", metaValue_buddhist_DateFormatItem_h },
+            { "roc.DateFormatItem.EBh", metaValue_generic_DateFormatItem_EBh },
             { "roc.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
             { "roc.DateFormatItem.GyMd", metaValue_generic_DateFormatItem_yyyyMd },
             { "roc.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_yyyyMMMEd },
@@ -580,6 +623,7 @@ public class FormatData_dsb extends ListResourceBundle {
             { "roc.DateFormatItem.yMMMM", metaValue_generic_DateFormatItem_yMMMM },
             { "roc.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
             { "roc.DateFormatItem.yQQQQ", metaValue_generic_DateFormatItem_yQQQQ },
+            { "roc.DateFormatItem.GyM", metaValue_generic_DateFormatItem_GyM },
             { "roc.DateFormatItem.GyMMM", metaValue_generic_DateFormatItem_yyyyMMM },
             { "islamic.DayNames", metaValue_generic_DayNames },
             { "islamic.DayAbbreviations", metaValue_generic_DayAbbreviations },
@@ -595,6 +639,7 @@ public class FormatData_dsb extends ListResourceBundle {
             { "islamic.DateFormatItem.Ehms", metaValue_generic_DateFormatItem_Ehms },
             { "islamic.DateFormatItem.Ehm", metaValue_generic_DateFormatItem_Ehm },
             { "islamic.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
+            { "islamic.DateFormatItem.hv", metaValue_generic_DateFormatItem_hv },
             { "islamic.DateFormatItem.hms", metaValue_generic_DateFormatItem_hms },
             { "islamic.DateFormatItem.Gy", metaValue_generic_DateFormatItem_Gy },
             { "islamic.DateFormatItem.GyMMMd", metaValue_generic_DateFormatItem_yyyyMMMd },
@@ -605,14 +650,18 @@ public class FormatData_dsb extends ListResourceBundle {
             { "islamic.DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
             { "islamic.DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
             { "islamic.DateFormatItem.yMMM", metaValue_generic_DateFormatItem_yMMM },
+            { "islamic.DateFormatItem.Hv", metaValue_generic_DateFormatItem_Hv },
             { "islamic.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
             { "islamic.DateFormatItem.Ed", metaValue_generic_DateFormatItem_Ed },
             { "islamic.DateFormatItem.MMMMd", metaValue_generic_DateFormatItem_MMMMd },
             { "islamic.DateFormatItem.H", metaValue_generic_DateFormatItem_H },
             { "islamic.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
             { "islamic.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
+            { "islamic.DateFormatItem.GyMEd", metaValue_generic_DateFormatItem_GyMEd },
             { "islamic.DateFormatItem.d", metaValue_generic_DateFormatItem_d },
+            { "islamic.DateFormatItem.Bh", metaValue_generic_DateFormatItem_Bh },
             { "islamic.DateFormatItem.h", metaValue_buddhist_DateFormatItem_h },
+            { "islamic.DateFormatItem.EBh", metaValue_generic_DateFormatItem_EBh },
             { "islamic.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
             { "islamic.DateFormatItem.GyMd", metaValue_generic_DateFormatItem_yyyyMd },
             { "islamic.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_yyyyMMMEd },
@@ -624,12 +673,14 @@ public class FormatData_dsb extends ListResourceBundle {
             { "islamic.DateFormatItem.yMMMM", metaValue_generic_DateFormatItem_yMMMM },
             { "islamic.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
             { "islamic.DateFormatItem.yQQQQ", metaValue_generic_DateFormatItem_yQQQQ },
+            { "islamic.DateFormatItem.GyM", metaValue_generic_DateFormatItem_GyM },
             { "islamic.DateFormatItem.GyMMM", metaValue_generic_DateFormatItem_yyyyMMM },
             { "islamic-civil.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
             { "islamic-civil.DateFormatItem.yMMMEd", metaValue_generic_DateFormatItem_yMMMEd },
             { "islamic-civil.DateFormatItem.Ehms", metaValue_generic_DateFormatItem_Ehms },
             { "islamic-civil.DateFormatItem.Ehm", metaValue_generic_DateFormatItem_Ehm },
             { "islamic-civil.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
+            { "islamic-civil.DateFormatItem.hv", metaValue_generic_DateFormatItem_hv },
             { "islamic-civil.DateFormatItem.hms", metaValue_generic_DateFormatItem_hms },
             { "islamic-civil.DateFormatItem.Gy", metaValue_generic_DateFormatItem_Gy },
             { "islamic-civil.DateFormatItem.GyMMMd", metaValue_generic_DateFormatItem_yyyyMMMd },
@@ -640,14 +691,18 @@ public class FormatData_dsb extends ListResourceBundle {
             { "islamic-civil.DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
             { "islamic-civil.DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
             { "islamic-civil.DateFormatItem.yMMM", metaValue_generic_DateFormatItem_yMMM },
+            { "islamic-civil.DateFormatItem.Hv", metaValue_generic_DateFormatItem_Hv },
             { "islamic-civil.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
             { "islamic-civil.DateFormatItem.Ed", metaValue_generic_DateFormatItem_Ed },
             { "islamic-civil.DateFormatItem.MMMMd", metaValue_generic_DateFormatItem_MMMMd },
             { "islamic-civil.DateFormatItem.H", metaValue_generic_DateFormatItem_H },
             { "islamic-civil.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
             { "islamic-civil.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
+            { "islamic-civil.DateFormatItem.GyMEd", metaValue_generic_DateFormatItem_GyMEd },
             { "islamic-civil.DateFormatItem.d", metaValue_generic_DateFormatItem_d },
+            { "islamic-civil.DateFormatItem.Bh", metaValue_generic_DateFormatItem_Bh },
             { "islamic-civil.DateFormatItem.h", metaValue_buddhist_DateFormatItem_h },
+            { "islamic-civil.DateFormatItem.EBh", metaValue_generic_DateFormatItem_EBh },
             { "islamic-civil.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
             { "islamic-civil.DateFormatItem.GyMd", metaValue_generic_DateFormatItem_yyyyMd },
             { "islamic-civil.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_yyyyMMMEd },
@@ -659,12 +714,14 @@ public class FormatData_dsb extends ListResourceBundle {
             { "islamic-civil.DateFormatItem.yMMMM", metaValue_generic_DateFormatItem_yMMMM },
             { "islamic-civil.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
             { "islamic-civil.DateFormatItem.yQQQQ", metaValue_generic_DateFormatItem_yQQQQ },
+            { "islamic-civil.DateFormatItem.GyM", metaValue_generic_DateFormatItem_GyM },
             { "islamic-civil.DateFormatItem.GyMMM", metaValue_generic_DateFormatItem_yyyyMMM },
             { "islamic-umalqura.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
             { "islamic-umalqura.DateFormatItem.yMMMEd", metaValue_generic_DateFormatItem_yMMMEd },
             { "islamic-umalqura.DateFormatItem.Ehms", metaValue_generic_DateFormatItem_Ehms },
             { "islamic-umalqura.DateFormatItem.Ehm", metaValue_generic_DateFormatItem_Ehm },
             { "islamic-umalqura.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
+            { "islamic-umalqura.DateFormatItem.hv", metaValue_generic_DateFormatItem_hv },
             { "islamic-umalqura.DateFormatItem.hms", metaValue_generic_DateFormatItem_hms },
             { "islamic-umalqura.DateFormatItem.Gy", metaValue_generic_DateFormatItem_Gy },
             { "islamic-umalqura.DateFormatItem.GyMMMd", metaValue_generic_DateFormatItem_yyyyMMMd },
@@ -675,14 +732,18 @@ public class FormatData_dsb extends ListResourceBundle {
             { "islamic-umalqura.DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
             { "islamic-umalqura.DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
             { "islamic-umalqura.DateFormatItem.yMMM", metaValue_generic_DateFormatItem_yMMM },
+            { "islamic-umalqura.DateFormatItem.Hv", metaValue_generic_DateFormatItem_Hv },
             { "islamic-umalqura.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
             { "islamic-umalqura.DateFormatItem.Ed", metaValue_generic_DateFormatItem_Ed },
             { "islamic-umalqura.DateFormatItem.MMMMd", metaValue_generic_DateFormatItem_MMMMd },
             { "islamic-umalqura.DateFormatItem.H", metaValue_generic_DateFormatItem_H },
             { "islamic-umalqura.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
             { "islamic-umalqura.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
+            { "islamic-umalqura.DateFormatItem.GyMEd", metaValue_generic_DateFormatItem_GyMEd },
             { "islamic-umalqura.DateFormatItem.d", metaValue_generic_DateFormatItem_d },
+            { "islamic-umalqura.DateFormatItem.Bh", metaValue_generic_DateFormatItem_Bh },
             { "islamic-umalqura.DateFormatItem.h", metaValue_buddhist_DateFormatItem_h },
+            { "islamic-umalqura.DateFormatItem.EBh", metaValue_generic_DateFormatItem_EBh },
             { "islamic-umalqura.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
             { "islamic-umalqura.DateFormatItem.GyMd", metaValue_generic_DateFormatItem_yyyyMd },
             { "islamic-umalqura.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_yyyyMMMEd },
@@ -694,6 +755,7 @@ public class FormatData_dsb extends ListResourceBundle {
             { "islamic-umalqura.DateFormatItem.yMMMM", metaValue_generic_DateFormatItem_yMMMM },
             { "islamic-umalqura.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
             { "islamic-umalqura.DateFormatItem.yQQQQ", metaValue_generic_DateFormatItem_yQQQQ },
+            { "islamic-umalqura.DateFormatItem.GyM", metaValue_generic_DateFormatItem_GyM },
             { "islamic-umalqura.DateFormatItem.GyMMM", metaValue_generic_DateFormatItem_yyyyMMM },
             { "calendarname.islamic-civil", "islamski ciwilny kalendaŕ" },
             { "calendarname.islamic", "islamski kalender" },
